@@ -10,5 +10,10 @@ class TelegramIdMatchError(Exception):
 
 class AuthorizationFieldError(Exception):
     def __init__(self,message="No Authorization field in headers"):
+        self.message = message
+        super().__init__(self.message)
+
+class JWSecretsError(Exception):
+    def __init__(self,message="JWSecret mismatch"):
         self.message = message
         super().__init__(self.message)
\ No newline at end of file
